@@ -29,7 +29,7 @@ if compas.RHINO:
     from .utilities import *  # noqa: F401 F403
 
 
-__version__ = '0.18.1'
+__version__ = '1.0.0'
 
 
 PURGE_ON_DELETE = True
@@ -57,10 +57,12 @@ def _check_rhino_version(version):
 def _get_ironpython_lib_path(version):
     version = _check_rhino_version(version)
 
-    if compas._os.system == 'win32':
+    if compas.WINDOWS:
         ironpython_lib_path = _get_ironpython_lib_path_win32(version)
-    elif compas._os.system == 'darwin':
+
+    elif compas.OSX:
         ironpython_lib_path = _get_ironpython_lib_path_mac(version)
+
     else:
         raise Exception('Unsupported platform')
 
@@ -86,7 +88,7 @@ def _get_ironpython_lib_path_mac(version):
     lib_paths = {
         '5.0': ['/', 'Applications', 'Rhinoceros.app', 'Contents'],
         '6.0': ['/', 'Applications', 'Rhinoceros.app', 'Contents', 'Frameworks', 'RhCore.framework', 'Versions', 'A'],
-        '7.0': ['/', 'Applications', 'RhinoWIP.app', 'Contents', 'Frameworks', 'RhCore.framework', 'Versions', 'A']
+        '7.0': ['/', 'Applications', 'Rhino 7.app', 'Contents', 'Frameworks', 'RhCore.framework', 'Versions', 'A']
     }
     return os.path.join(*lib_paths.get(version) + ['Resources', 'ManagedPlugIns', 'RhinoDLR_Python.rhp', 'Lib'])
 
@@ -94,10 +96,12 @@ def _get_ironpython_lib_path_mac(version):
 def _get_python_plugins_path(version):
     version = _check_rhino_version(version)
 
-    if compas._os.system == 'win32':
+    if compas.WINDOWS:
         python_plugins_path = _get_python_plugins_path_win32(version)
-    elif compas._os.system == 'darwin':
+
+    elif compas.OSX:
         python_plugins_path = _get_python_plugins_path_mac(version)
+
     else:
         raise Exception('Unsupported platform')
 
@@ -139,10 +143,12 @@ def _get_python_plugins_path_mac(version):
 def _get_scripts_path(version):
     version = _check_rhino_version(version)
 
-    if compas._os.system == 'win32':
+    if compas.WINDOWS:
         scripts_path = _get_scripts_path_win32(version)
-    elif compas._os.system == 'darwin':
+
+    elif compas.OSX:
         scripts_path = _get_scripts_path_mac(version)
+
     else:
         raise Exception('Unsupported platform')
 
